@@ -4,7 +4,7 @@ use warnings;
 our (%gui, %vmc);
 
 sub init_edit_gen_encryption {
-    &busy_pointer($gui{dialogEdit}, 1);
+    &set_pointer($gui{d}{Edit}{dialog}, 'watch');
     # Determine if we have anything encrypted
     my @IMediumAttachment = IMachine_getMediumAttachments($vmc{IMachine});
     my $encrypted = 0;
@@ -18,15 +18,16 @@ sub init_edit_gen_encryption {
         }
     }
 
-    $gui{checkbuttonEditGenEncryption}->set_active($encrypted);
-    $gui{entryEditGenEncryptionPass}->set_text('');
-    $gui{entryEditGenEncryptionPassCon}->set_text('');
-    &busy_pointer($gui{dialogEdit}, 0);
+    $gui{d}{Edit}{checkGenEncryption}->set_active($encrypted);
+    $gui{d}{Edit}{entryGenPass}->set_text('');
+    $gui{d}{Edit}{entryGenConfirm}->set_text('');
+    $gui{d}{Edit}{gridGenEncryption}->set_sensitive($encrypted);
+    &set_pointer($gui{d}{Edit}{dialog});
 }
 
 # Toggles GUI based on encrypted disks being attached
 sub gen_encryption {
-        my $state = $gui{checkbuttonEditGenEncryption}->get_active();
-        $gui{tableEditGenEncryption}->set_sensitive($state);
+        my $state = $gui{d}{Edit}{checkGenEncryption}->get_active();
+        $gui{d}{Edit}{gridGenEncryption}->set_sensitive($state);
 }
 1;
