@@ -3,6 +3,8 @@ use strict;
 use warnings;
 our (%gui, %signal, %vmc);
 
+# NOTE: Despite what the SDK claims HostOnlyNetwork is not implemented
+
 sub init_edit_network {
     &set_pointer($gui{d}{Edit}{dialog}, 'watch');
     $gui{d}{Edit}{cboxNetworkAdapter}->signal_handler_block($signal{Edit_cboxNetworkAdapter_changed});
@@ -28,8 +30,12 @@ sub init_edit_network {
     &combobox_set_active_text($gui{d}{Edit}{cboxNetworkPromisc}, INetworkAdapter_getPromiscModePolicy($INetworkAdapter), 1);
 
     if ($AttachType eq 'Bridged') { &net_gui_bridged($INetworkAdapter); }
-    elsif ($AttachType eq 'HostOnlyNetwork') { &net_gui_hon_named($INetworkAdapter); }
-    elsif ($AttachType eq 'HostOnly') { &net_gui_hon(); }
+    elsif ($AttachType eq 'HostOnlyNetwork') {
+        # HostOnlyNetwork: Does not seem to be implemented even though SDK says it is - so make it HostOnly instead
+        INetworkAdapter_setAttachmentType($INetworkAdapter, 'HostOnly');
+        &net_gui_hon_named($INetworkAdapter);
+    }
+    elsif ($AttachType eq 'HostOnly') { &net_gui_hon_named($INetworkAdapter); }
     elsif ($AttachType eq 'Internal') { &net_gui_internal($INetworkAdapter); }
     elsif ($AttachType eq 'Generic') { &net_gui_generic($INetworkAdapter); }
     elsif ($AttachType eq 'NATNetwork') { &net_gui_nat_named($INetworkAdapter); }
@@ -138,10 +144,8 @@ sub net_attach {
     my $AttachType = &getsel_combo($widget, 1);
     $gui{d}{Edit}{lstoreNetworkName}->clear();
     INetworkAdapter_setAttachmentType($INetworkAdapter, $AttachType);
-
     if ($AttachType eq 'Bridged') { &net_gui_bridged($INetworkAdapter); }
-    elsif ($AttachType eq 'HostOnlyNetwork') { &net_gui_hon_named($INetworkAdapter); }
-    elsif ($AttachType eq 'HostOnly') { &net_gui_hon(); }
+    elsif ($AttachType eq 'HostOnly') { &net_gui_hon_named($INetworkAdapter); }
     elsif ($AttachType eq 'Internal') { &net_gui_internal($INetworkAdapter); }
     elsif ($AttachType eq 'Generic') { &net_gui_generic($INetworkAdapter); }
     elsif ($AttachType eq 'NATNetwork') { &net_gui_nat_named($INetworkAdapter); }
@@ -160,9 +164,9 @@ sub net_name {
     my $netname = &getsel_combo($gui{d}{Edit}{cboxNetworkName}, 0);
 
     if ($netname) { # If there's no netname then we cannot attach (eg there may be not HON or NATNets defined)
-        if ($AttachType eq 'Bridged') { INetworkAdapter_setBridgedInterface($INetworkAdapter, $netname); }
-        elsif ($AttachType eq 'NATNetwork') { INetworkAdapter_setNATNetwork($INetworkAdapter, $netname); }
-        elsif ($AttachType eq 'HostOnly') { INetworkAdapter_setHostOnlyInterface($INetworkAdapter, $netname); }
+        if ($AttachType eq 'Bridged') { INetworkAdapter_setBridgedInterface($INetworkAdapter, $netname) if defined($netname); }
+        elsif ($AttachType eq 'NATNetwork') { INetworkAdapter_setNATNetwork($INetworkAdapter, $netname) if defined($netname); }
+        elsif ($AttachType eq 'HostOnly') { INetworkAdapter_setHostOnlyInterface($INetworkAdapter, $netname) if defined($netname); }
     }
 }
 
@@ -228,11 +232,14 @@ sub net_gui_hon_named {
     my $hostonlyface = INetworkAdapter_getHostOnlyInterface($INetworkAdapter);
 
     foreach my $interface (@IHostNetworkInterface) {
+
         if (IHostNetworkInterface_getInterfaceType($interface) eq 'HostOnly') {
             my $name = IHostNetworkInterface_getName($interface);
             my $iter = $gui{d}{Edit}{lstoreNetworkName}->append();
             $gui{d}{Edit}{lstoreNetworkName}->set($iter, 0, $name);
-            $gui{d}{Edit}{cboxNetworkName}->set_active_iter($iter) if ($name eq $hostonlyface);
+            if (defined($hostonlyface)) {
+                $gui{d}{Edit}{cboxNetworkName}->set_active_iter($iter) if ($name eq $hostonlyface);
+            }
         }
     }
 
@@ -299,21 +306,6 @@ sub net_gui_internal {
     $gui{d}{Edit}{tvNetworkGenericprop}->hide();
 }
 
-sub net_gui_hon {
-    $gui{d}{Edit}{labelNetworkName}->hide();
-    $gui{d}{Edit}{cboxNetworkName}->hide();
-    $gui{d}{Edit}{labelNetworkInternal}->hide();
-    $gui{d}{Edit}{ecboxNetworkInternal}->hide();
-    $gui{d}{Edit}{labelNetworkGeneric}->hide();
-    $gui{d}{Edit}{ecboxNetworkGeneric}->hide();
-    $gui{d}{Edit}{labelNetworkPromisc}->hide();
-    $gui{d}{Edit}{cboxNetworkPromisc}->hide();
-    $gui{d}{Edit}{labelNetworkGenericprop}->hide();
-    $gui{d}{Edit}{frameNetworkGenericprop}->hide();
-    $gui{d}{Edit}{tvNetworkGenericprop}->hide();
-}
-
-
 sub net_gui_nat {
     $gui{d}{Edit}{labelNetworkName}->hide();
     $gui{d}{Edit}{cboxNetworkName}->hide();
