@@ -113,7 +113,7 @@ sub storage_ctr_add {
 
     foreach my $ctr (@ctrs) { $exists = 1 if (IStorageController_getBus($ctr) eq $bus) }
 
-    if ($exists) { &show_err_msg('ctrallocated'); }
+    if ($exists) { &show_err_msg('ctrallocated', 0); }
     else {
         my $IStorageController = IMachine_addStorageController($vmc{IMachine}, $ctrname, $bus);
         IStorageController_setPortCount($IStorageController, IStorageController_getMinPortCount($IStorageController)); # Controllers have all ports on by default. Set to the minimum
@@ -134,7 +134,7 @@ sub storage_attach_hd {
     }
 
     # If medium wasn't attached, controller must be full
-    if (!$attached) { &show_err_msg('ctrfull'); }
+    if (!$attached) { &show_err_msg('ctrfull', 0); }
 
     IMachine_saveSettings($vmc{IMachine});
     &addrow_msg_log("Settings explicitly saved for $vmc{Name} due to storage attachment.");
@@ -169,7 +169,7 @@ sub storage_attach_removable {
         }
 
         # If medium wasn't attached, controller must be full
-        if (!$attached) { &show_err_msg('ctrfull'); }
+        if (!$attached) { &show_err_msg('ctrfull', 0); }
     }
 
     IMachine_saveSettings($vmc{IMachine});
@@ -198,7 +198,7 @@ sub storage_ctr_rem {
     my $storref = &getsel_list_edit_storage();
     my @IMediumAttachments = IMachine_getMediumAttachmentsOfController($vmc{IMachine}, $$storref{ControllerName});
 
-    if (@IMediumAttachments) { &show_err_msg('ctrinuse'); }
+    if (@IMediumAttachments) { &show_err_msg('ctrinuse', 0); }
     else { IMachine_removeStorageController($vmc{IMachine}, $$storref{ControllerName}); }
 
     &fill_list_edit_storage($vmc{IMachine});
@@ -279,7 +279,7 @@ sub storage_connected_port {
         foreach my $attach (@IMediumAttachment) {
             if ($$attach{port} == $newport and $$attach{device} == $newdevice) {
                 $free = 0;
-                &show_err_msg('existattach');
+                &show_err_msg('existattach', 0);
                 last;
             }
         }
