@@ -106,7 +106,7 @@ sub sys_mother_efi {
 
             if (!$IUefiVariableStore) {
                 # If there's no UEFI variable store, then make one
-                show_err_msg('noefivariables', '');
+                &show_err_msg('noefivariables', 0, '');
                 INvramStore_initUefiVariableStore($vmc{INvramStore});
                 $IUefiVariableStore = INvramStore_getUefiVariableStore($vmc{INvramStore});
                 IUefiVariableStore_enrollDefaultMsSignatures($IUefiVariableStore);
@@ -174,7 +174,7 @@ sub sys_mother_secureboot {
         my $IUefiVariableStore = INvramStore_getUefiVariableStore($vmc{INvramStore});
 
         if (!defined($IUefiVariableStore)) {
-            &show_err_msg('nouefivarfile');
+            &show_err_msg('nouefivarfile', 0);
             INvramStore_initUefiVariableStore($vmc{INvramStore}, 0);
             $IUefiVariableStore = INvramStore_getUefiVariableStore($vmc{INvramStore});
         };
