@@ -75,10 +75,9 @@ our (%gui);
                                        'Could not change disc. This guest does not have a usable optical drive attached.',
                                        'warning'],
                 noextensions       => ['VirtualBox Extension Pack',
-                                       'This server does not have the Oracle VirtualBox Extension Pack or VNC Extension Pack installed. ' .
-                                       'You should install the Oracle Extension Pack if available for your OS, otherwise ' .
-                                       'install the VNC extension pack.' .
-                                       '    See URL: https://www.virtualbox.org/wiki/Downloads',
+                                       'This server does not have the Oracle VirtualBox Extension Pack or the VNC Extension Pack installed. ' .
+                                       'You should install the Oracle Extension Pack or VNX Extension Pack.' .
+                                       "\n    See URL: https://www.virtualbox.org/wiki/Downloads",
                                        'warning'],
                 noscreenshot       => ['Screenshot Failed',
                                        'Guest is not in a state suitable for screenshots or your' .
@@ -136,30 +135,34 @@ our (%gui);
                                        "you will need to reconnect.\n\n",
                                        'error'],
                 vboxver            => ['Unsupported VirtualBox Version',
-                                       'This version of RemoteBox is not supported with the version of VirtualBox on the' .
-                                       " server.\nVisit http://remotebox.knobgoblin.org.uk to download a compatible version of RemoteBox.\n" .
-                                       "RemoteBox will continue, but you may experience problems due to incompatibilities.\n\n" .
-                                       'Supported VirtualBox Version: 7.1.x',
+                                       'This version of RemoteBox is not supported with the version of VirtualBox on the server' .
+                                       ".\nVisit http://remotebox.knobgoblin.org.uk to download a compatible version of RemoteBox.\n" .
+                                       "\nRemoteBox will continue, but you may experience problems due to incompatibilities.\n\n" .
+                                       'Supported VirtualBox Version: 7.2.x',
                                        'warning'],
                 webservice         => ['VirtualBox Returned an Error',
                                        '',
                                        'error']);
 
     sub show_err_msg {
-        my ($key, $append) = @_;
-        my $dialog = $gui{d}{Error}{dialog};
+        my ($key, $surpress, $append) = @_;
         my ($title, $body, $type) = @{ $err{$key} };
-        $dialog = $gui{d}{Warning}{dialog} if ($type eq 'warning');
         $body .= "\n$append" if ($append);
-        &addrow_msg_log("Error Dialog:    $title:    $body");
-        $dialog->set_markup("<big><b>$title</b></big>");
-        $dialog->set_title($title);
-        # Filter out <> to avoid them being treated as markup
-        $body =~ s/\</&lt;/g;
-        $body =~ s/\>/&gt;/g;
-        $dialog->format_secondary_markup($body);
-        $dialog->run;
-        $dialog->hide;
+        &addrow_msg_log("Error / Warning Dialog:    $title:    $body");
+
+        # Don't show the dialog if it has been surpressed
+        if (!$surpress) {
+            my $dialog = $gui{d}{Error}{dialog};
+            $dialog = $gui{d}{Warning}{dialog} if ($type eq 'warning');
+            $dialog->set_markup("<big><b>$title</b></big>");
+            $dialog->set_title($title);
+            # Filter out <> to avoid them being treated as markup
+            $body =~ s/\</&lt;/g;
+            $body =~ s/\>/&gt;/g;
+            $dialog->format_secondary_markup($body);
+            $dialog->run;
+            $dialog->hide;
+        }
     }
 }
 
@@ -190,7 +193,7 @@ sub vboxerror {
             }
             # OK means continue (ie do nothing) - Cancel means disconnect
         }
-        else { &show_err_msg('webservice', $res->faultstring); }
+        else { &show_err_msg('webservice', 0, $res->faultstring); }
     }
     elsif (defined($$soap{_transport}{_proxy}{_http_response}{_content})) {
         # Fall back to this work-around for what appears to be a bug in some editions of perl soap lite
@@ -199,12 +202,12 @@ sub vboxerror {
         my $rawxml = $$soap{_transport}{_proxy}{_http_response}{_content};
         $rawxml =~ m/\<faultstring\>(.*)\<\/faultstring\>/;
         $errmsg = $1 if ($1);
-        &show_err_msg('webservice', $errmsg);
+        &show_err_msg('webservice', 0, $errmsg);
     }
     else {
         $gui{websn} = undef; # Invalidate current session to prevent deep recursion
         &virtualbox_logoff(1); # Cleanup - but logoff will not happen because session is invalidated
-        &show_err_msg('transport', $soap->transport->status);
+        &show_err_msg('transport', 0, $soap->transport->status);
     }
 }
 
@@ -214,10 +217,10 @@ sub vboxlogonerror {
         my ($soap, $res) = @_;
 
         if ($soap->transport->status =~ m/internal server error/i) {
-            &show_err_msg('connect', 'Login Denied. Please check your login credentials');
+            &show_err_msg('connect', 0, 'Login Denied. Please check your login credentials');
         }
         else {
-            &show_err_msg('connect', $soap->transport->status);
+            &show_err_msg('connect', 0, $soap->transport->status);
         }
         $gui{websn} = undef; # Invalidate current session to prevent deep recursion
         &virtualbox_logoff(1); # Cleanup - but logoff will not happen because session is invalidated
