@@ -64,7 +64,7 @@ sub show_dialog_new_guest {
 
         if ($response eq 'ok') {
             # Other entries do not require validation
-            if (!$gui{d}{New}{entryName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{New}{entryName}->get_text()) { &show_err_msg('invalidname', 0); }
             else {
                 $gui{d}{New}{dialog}->hide();
                 my $name = $gui{d}{New}{entryName}->get_text();
@@ -144,7 +144,7 @@ sub show_dialog_new_guest {
                     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
                     &fill_list_guest();
                 }
-                else { &show_err_msg('createguest', " ($name)"); }
+                else { &show_err_msg('createguest', 0, " ($name)"); }
             }
         }
         else { $gui{d}{New}{dialog}->hide(); }
@@ -163,7 +163,7 @@ sub show_dialogClone {
 
         if ($response eq 'ok') {
             # No validation needed for other entries
-            if (!$gui{d}{Clone}{entryName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{Clone}{entryName}->get_text()) { &show_err_msg('invalidname', 0); }
             else {
                 $gui{d}{Clone}{dialog}->hide;
 
@@ -286,7 +286,7 @@ sub create_new_dskimg_clone {
         $IMedium = undef;
     }
     elsif (IMedium_refreshState($IMedium) eq 'NotCreated') {
-        &show_err_msg('diskimgcreation', "Disk Image: $imgfile");
+        &show_err_msg('diskimgcreation', 0, "Disk Image: $imgfile");
         IManagedObjectRef_release($IMedium);
         $IMedium = undef;
     }
@@ -314,7 +314,7 @@ sub create_new_dskimg {
         $IMedium = undef;
     }
     elsif (IMedium_refreshState($IMedium) eq 'NotCreated') {
-        &show_err_msg('diskimgcreation', "Disk Image: $imgfile");
+        &show_err_msg('diskimgcreation', 0, "Disk Image: $imgfile");
         IManagedObjectRef_release($IMedium);
         $IMedium = undef;
     }
