@@ -2,33 +2,35 @@
 use strict;
 use warnings;
 our %gui;
-our %prefs = (RDPCLIENT         => 'xfreerdp /size:%Xx%Y /bpp:32 +clipboard /sound /t:"%n - RemoteBox" /v:%h:%p',
-              VNCCLIENT         => 'vncviewer -Shared -AcceptClipboard -SetPrimary -SendClipboard -SendPrimary -RemoteResize -DesktopSize %Xx%Y  %h:%p',
-              ADDADDITIONS      => 1,
-              RDPAUTOOPEN       => 1,
-              GUESTLISTEXPAND   => 1,
-              AUTOSORTGUESTLIST => 1,
-              EXTENDEDDETAILS   => 0,
-              SSLVERIFY         => 0,
-              DEFRDPPORTS       => '3389-4389',
-              DEFVNCPORTS       => '5900-5999',
-              AUTOHINTDISP      => 0,
-              AUTOHINTDISPX     => 1280,
-              AUTOHINTDISPY     => 1024,
-              AUTOHINTDISPD     => 32,
-              STOPTYPE          => 'INSTANT',
-              EXPANDDETGEN      => 1,
-              EXPANDDETSYS      => 1,
-              EXPANDDETDISP     => 1,
-              EXPANDDETSTOR     => 1,
-              EXPANDDETAUDIO    => 1,
-              EXPANDDETNET      => 1,
-              EXPANDDETIO       => 1,
-              EXPANDDETUSB      => 1,
-              EXPANDDETSHARE    => 1,
-              EXPANDDETRUN      => 1,
-              EXPANDDETDESC     => 1,
-              AUTOCONNPROF      => '');
+our %prefs = (RDPCLIENT           => 'xfreerdp /size:%Xx%Y /bpp:32 +clipboard /sound /t:"%n - RemoteBox" /v:%h:%p /d: /p: /cert:ignore',
+              VNCCLIENT           => 'vncviewer -Shared -AcceptClipboard -SetPrimary -SendClipboard -SendPrimary -RemoteResize -DesktopSize %Xx%Y  %h:%p',
+              ADDADDITIONS        => 1,
+              RDPAUTOOPEN         => 1,
+              GUESTLISTEXPAND     => 1,
+              AUTOSORTGUESTLIST   => 1,
+              EXTENDEDDETAILS     => 0,
+              SSLVERIFY           => 0,
+              DEFRDPPORTS         => '3389-4389',
+              DEFVNCPORTS         => '5900-5999',
+              AUTOHINTDISP        => 0,
+              AUTOHINTDISPX       => 1280,
+              AUTOHINTDISPY       => 1024,
+              AUTOHINTDISPD       => 32,
+              STOPTYPE            => 'INSTANT',
+              EXPANDDETGEN        => 1,
+              EXPANDDETSYS        => 1,
+              EXPANDDETDISP       => 1,
+              EXPANDDETSTOR       => 1,
+              EXPANDDETAUDIO      => 1,
+              EXPANDDETNET        => 1,
+              EXPANDDETIO         => 1,
+              EXPANDDETUSB        => 1,
+              EXPANDDETSHARE      => 1,
+              EXPANDDETRUN        => 1,
+              EXPANDDETDESC       => 1,
+              NOEXTPACKWARNDIALOG => 0,
+              NOVERSIONWARNDIALOG => 0,
+              AUTOCONNPROF        => '');
 
 # Import the current remotebox preferences
 sub rbprefs_get {
@@ -85,7 +87,7 @@ sub rbprefs_save {
     else { warn "Unable to save preferences: $gui{CONFIGFILE}\n"; }
 }
 
-# Saves the profiles.DO NOT call this from rbprefs_save otherwise there will be
+# Saves the profiles. DO NOT call this from rbprefs_save otherwise there will be
 # a race condition which will empty the profiles file.
 sub rbprofiles_save {
     # As this file might contain passwords, we'll create it 0600, but only if it's the first time we're creating it.
@@ -165,8 +167,8 @@ sub show_dialog_editnat {
 
         if ($response eq 'ok') {
             # Other entries do not require validation
-            if (!$gui{d}{NAT}{entryName}->get_text()) { &show_err_msg('invalidname'); }
-            elsif (!&valid_cidr($gui{d}{NAT}{entryCIDR}->get_text())) { &show_err_msg('invalidipv4cidr', '(Network CIDR)'); }
+            if (!$gui{d}{NAT}{entryName}->get_text()) { &show_err_msg('invalidname', 0); }
+            elsif (!&valid_cidr($gui{d}{NAT}{entryCIDR}->get_text())) { &show_err_msg('invalidipv4cidr', 0, '(Network CIDR)'); }
             else {
                 $gui{d}{NAT}{dialog}->hide;
                 INATNetwork_setNetworkName($$natref{INATNetwork}, $gui{d}{NAT}{entryName}->get_text());
@@ -205,9 +207,9 @@ sub show_dialog_pf4 {
 
         if ($response eq 'ok') {
             # No validation needed for other entries
-            if (!$gui{d}{PFRule4}{entryName}->get_text()) { &show_err_msg('invalidname'); }
-            elsif (!valid_ipv4($gui{d}{PFRule4}{entryHostIP}->get_text())) { &show_err_msg('invalidipv4address', '(Host IP)'); }
-            elsif (!valid_ipv4($gui{d}{PFRule4}{entryGuestIP}->get_text())) { &show_err_msg('invalidipv4address', '(Guest IP)'); }
+            if (!$gui{d}{PFRule4}{entryName}->get_text()) { &show_err_msg('invalidname', 0); }
+            elsif (!valid_ipv4($gui{d}{PFRule4}{entryHostIP}->get_text())) { &show_err_msg('invalidipv4address', 0, '(Host IP)'); }
+            elsif (!valid_ipv4($gui{d}{PFRule4}{entryGuestIP}->get_text())) { &show_err_msg('invalidipv4address', 0, '(Guest IP)'); }
             else {
                 $gui{d}{PFRule4}{dialog}->hide;
                 my $natref = &getsel_list_vbprefsnat();
@@ -251,9 +253,9 @@ sub show_dialog_pf6 {
 
         if ($response eq 'ok') {
             # No validation needed for other entries
-            if (!$gui{d}{PFRule6}{entryName}->get_text()) { &show_err_msg('invalidname', '(Portforwarding rule name)'); }
-            elsif (!valid_ipv6($gui{d}{PFRule6}{entryHostIP}->get_text())) { &show_err_msg('invalidipv6address', '(Host IP)'); }
-            elsif (!valid_ipv6($gui{d}{PFRule6}{entryGuestIP}->get_text())) { &show_err_msg('invalidipv6address', '(Guest IP)'); }
+            if (!$gui{d}{PFRule6}{entryName}->get_text()) { &show_err_msg('invalidname', 0, '(Portforwarding rule name)'); }
+            elsif (!valid_ipv6($gui{d}{PFRule6}{entryHostIP}->get_text())) { &show_err_msg('invalidipv6address', 0, '(Host IP)'); }
+            elsif (!valid_ipv6($gui{d}{PFRule6}{entryGuestIP}->get_text())) { &show_err_msg('invalidipv6address', 0, '(Guest IP)'); }
             else {
                 $gui{d}{PFRule6}{dialog}->hide;
                 my $natref = &getsel_list_vbprefsnat();
@@ -295,6 +297,8 @@ sub show_dialog_prefs {
     $gui{d}{Prefs}{checkOpenDisplay}->set_active($prefs{RDPAUTOOPEN});
     $gui{d}{Prefs}{checkAdditions}->set_active($prefs{ADDADDITIONS});
     $gui{d}{Prefs}{checkSortGuest}->set_active($prefs{AUTOSORTGUESTLIST});
+    $gui{d}{Prefs}{checkNoExtPackWarn}->set_active($prefs{NOEXTPACKWARNDIALOG});
+    $gui{d}{Prefs}{checkNoVersionWarn}->set_active($prefs{NOVERSIONWARNDIALOG});
     $gui{d}{Prefs}{checkAutoHint}->set_active($prefs{AUTOHINTDISP});
     $gui{d}{Prefs}{sbWidth}->set_value($prefs{AUTOHINTDISPX});
     $gui{d}{Prefs}{sbHeight}->set_value($prefs{AUTOHINTDISPY});
@@ -317,6 +321,8 @@ sub show_dialog_prefs {
         $prefs{RDPAUTOOPEN} = int($gui{d}{Prefs}{checkOpenDisplay}->get_active());
         $prefs{ADDADDITIONS} = int($gui{d}{Prefs}{checkAdditions}->get_active());
         $prefs{AUTOSORTGUESTLIST} = int($gui{d}{Prefs}{checkSortGuest}->get_active());
+        $prefs{NOEXTPACKWARNDIALOG} = int($gui{d}{Prefs}{checkNoExtPackWarn}->get_active());
+        $prefs{NOVERSIONWARNDIALOG} = int($gui{d}{Prefs}{checkNoVersionWarn}->get_active());
         $prefs{STOPTYPE} = &getsel_combo($gui{d}{Prefs}{cboxStop}, 1);
         $prefs{AUTOHINTDISP} = int($gui{d}{Prefs}{checkAutoHint}->get_active());
         $prefs{AUTOHINTDISPX} = int($gui{d}{Prefs}{sbWidth}->get_value());
@@ -412,33 +418,33 @@ sub show_dialog_edithon {
 
             if (!valid_ipv4($gui{d}{HON}{entryIPV4Addr}->get_text())) {
                 $valid = FALSE;
-                &show_err_msg('invalidipv4address', '(Adapter IPv4 Address)');
+                &show_err_msg('invalidipv4address', 0, '(Adapter IPv4 Address)');
             }
             elsif (!valid_ipv4($gui{d}{HON}{entryIPV4Netmask}->get_text())) {
                 $valid = FALSE;
-                &show_err_msg('invalidipv4netmask', '(Adapter IPv4 Netmask)');
+                &show_err_msg('invalidipv4netmask', 0, '(Adapter IPv4 Netmask)');
             }
             elsif ($ipv6addr and !valid_ipv6($ipv6addr)) {
                 $valid = FALSE;
-                &show_err_msg('invalidipv6address', '(Adapter IPv6 Address)');
+                &show_err_msg('invalidipv6address', 0, '(Adapter IPv6 Address)');
             }
 
             if ($active) {
                 if (!valid_ipv4($gui{d}{HON}{entryServerAddr}->get_text())) {
                     $valid = FALSE;
-                    &show_err_msg('invalidipv4address', '(DHCP Server Address)');
+                    &show_err_msg('invalidipv4address', 0, '(DHCP Server Address)');
                 }
                 elsif (!valid_ipv4($gui{d}{HON}{entryServerNetmask}->get_text())) {
                     $valid = FALSE;
-                    &show_err_msg('invalidipv4netmask', '(DHCP Server Netmask)');
+                    &show_err_msg('invalidipv4netmask', 0, '(DHCP Server Netmask)');
                 }
                 elsif (!valid_ipv4($gui{d}{HON}{entryLowerBound}->get_text())) {
                     $valid = FALSE;
-                    &show_err_msg('invalidipv4address', '(DHCP Server Lower Address Bound)');
+                    &show_err_msg('invalidipv4address', 0, '(DHCP Server Lower Address Bound)');
                 }
                 elsif (!valid_ipv4($gui{d}{HON}{entryUpperBound}->get_text())) {
                     $valid = FALSE;
-                    &show_err_msg('invalidipv4address', '(DHCP Server Upper Address Bound)');
+                    &show_err_msg('invalidipv4address', 0, '(DHCP Server Upper Address Bound)');
                 }
             }
 
