@@ -100,7 +100,7 @@ sub vmm_release {
         }
     }
 
-    if ($warn == 1) { &show_err_msg('mediuminuse', "\nMedium: $$mediumref{Name}"); }
+    if ($warn == 1) { &show_err_msg('mediuminuse', 0, "\nMedium: $$mediumref{Name}"); }
     else { &addrow_msg_log("Medium $$mediumref{Name} released."); }
 
     if ($page == 0) { &fill_list_vmmhd(); }
@@ -127,7 +127,7 @@ sub vmm_rem {
                 &addrow_msg_log("Deleted hard disk $$hdref{Name}.");
                 &fill_list_vmmhd();
             }
-            else { &show_err_msg('deletemedium', "\nMedium: $$hdref{Name}"); }
+            else { &show_err_msg('deletemedium', 0, "\nMedium: $$hdref{Name}"); }
         }
         elsif ($response eq '2') { # Removes Disk
             IMedium_close($$hdref{IMedium});
@@ -159,7 +159,7 @@ sub vmm_compact {
         &addrow_msg_log("Compacted disk image $$hdref{Name}");
         &fill_list_vmmhd();
     }
-    else { &show_err_msg('compactmedium', "\nMedium: $$hdref{Name}\nCurrent State: $MediumState"); }
+    else { &show_err_msg('compactmedium', 0, "\nMedium: $$hdref{Name}\nCurrent State: $MediumState"); }
 }
 
 # Move a medium to a new location
@@ -287,7 +287,7 @@ sub show_dialog_vmm_modify {
             &show_progress_window($IProgress, 'Resizing Virtual Hard Disk Image', $gui{pb}{ProgressMediaResize}) if ($IProgress);
             my $MediumState = IMedium_refreshState($$hdref{IMedium}); # Make sure VB sees any size changes
             my $refreshsize = IMedium_getLogicalSize($$hdref{IMedium});
-            &show_err_msg('nohdresize', "\nMedium: $$hdref{Name}\nCurrent State: $MediumState") if (($refreshsize / 1048576) < $newhdsizemb); # See if actually got resized, not all types support resizing
+            &show_err_msg('nohdresize', 0, "\nMedium: $$hdref{Name}\nCurrent State: $MediumState") if (($refreshsize / 1048576) < $newhdsizemb); # See if actually got resized, not all types support resizing
         }
 
         my $newtype = &getsel_combo($gui{d}{ModifyHD}{cboxType}, 0);
@@ -421,7 +421,7 @@ sub show_dialog_create_floppy {
 
         if ($response eq 'ok') {
             # No validation needed on other entries
-            if (!$gui{d}{CreateFloppy}{entryImage}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{CreateFloppy}{entryImage}->get_text()) { &show_err_msg('invalidname', 0); }
             else {
                 $gui{d}{CreateFloppy}{dialog}->hide;
                 my ($vol, $dir, $file) = &rsplitpath($gui{d}{CreateFloppy}{entryImage}->get_text());
@@ -464,7 +464,7 @@ sub show_dialog_create_hd {
 
         if ($response eq 'ok') {
             # No validation needed on other entries
-            if (!$gui{d}{CreateHD}{entryImage}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{CreateHD}{entryImage}->get_text()) { &show_err_msg('invalidname', 0); }
             else {
                 $gui{d}{CreateHD}{dialog}->hide;
                 my ($vol, $dir, $file) = &rsplitpath($gui{d}{CreateHD}{entryImage}->get_text());
