@@ -98,6 +98,12 @@ sub SOAP::Serializer::as_CPUArchitecture {
     return [$name, {'xsi:type' => 'vbox:CPUArchitecture', %$attr}, $value];
 }
 
+sub SOAP::Serializer::as_CPUPropertyTypeARM {
+    my $self = shift;
+    my ($value, $name, $type, $attr) = @_;
+    return [$name, {'xsi:type' => 'vbox:CPUPropertyTypeARM', %$attr}, $value];
+}
+
 sub SOAP::Serializer::as_CPUPropertyTypeX86 {
     my $self = shift;
     my ($value, $name, $type, $attr) = @_;
